@@ -8,6 +8,8 @@ from functools import reduce
 import hashlib
 import base64
 
+from .to_bytes import to_bytes
+
 
 def represent_and_encode(obj):
 	class_representation = f'{obj.__class__.__module__}|{obj.__class__.__name__}'
@@ -103,9 +105,11 @@ def make_dataframe_hashable(data):
 
 	# convert each value in the column into an int hash
 	def _hash_int(x):
-		x = represent_and_encode(x)
+		s = represent_and_encode(x)
 		_hash_maker = hashlib.sha256()
-		_hash_maker.update(x.encode())
+
+		encoded = to_bytes(s)  # instead of x.encode()
+		_hash_maker.update(encoded)
 		return hash(base64.b64encode(_hash_maker.digest()).decode())
 
 	if use == 'spark':
